@@ -26,6 +26,29 @@ class GsClient(AbstractClient):
     _service = 'gs'
 
 
+    def BackUpAndroidInstanceToStorage(self, request):
+        """备份云手机到指定存储
+
+        :param request: Request instance for BackUpAndroidInstanceToStorage.
+        :type request: :class:`tencentcloud.gs.v20191118.models.BackUpAndroidInstanceToStorageRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.BackUpAndroidInstanceToStorageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BackUpAndroidInstanceToStorage", params, headers=headers)
+            response = json.loads(body)
+            model = models.BackUpAndroidInstanceToStorageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ConnectAndroidInstance(self, request):
         """连接安卓实例
 
@@ -76,6 +99,52 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAndroidApp(self, request):
+        """创建安卓应用
+
+        :param request: Request instance for CreateAndroidApp.
+        :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidAppRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.CreateAndroidAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAndroidApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAndroidAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateAndroidAppVersion(self, request):
+        """创建安卓应用版本
+
+        :param request: Request instance for CreateAndroidAppVersion.
+        :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidAppVersionRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.CreateAndroidAppVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAndroidAppVersion", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAndroidAppVersionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAndroidInstanceImage(self, request):
         """创建安卓实例镜像
 
@@ -191,6 +260,52 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAndroidInstancesScreenshot(self, request):
+        """安卓实例截图
+
+        :param request: Request instance for CreateAndroidInstancesScreenshot.
+        :type request: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstancesScreenshotRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.CreateAndroidInstancesScreenshotResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAndroidInstancesScreenshot", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAndroidInstancesScreenshotResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateCosCredential(self, request):
+        """用于创建 Cos 临时密钥
+
+        :param request: Request instance for CreateCosCredential.
+        :type request: :class:`tencentcloud.gs.v20191118.models.CreateCosCredentialRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.CreateCosCredentialResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateCosCredential", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateCosCredentialResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateSession(self, request):
         """创建会话
 
@@ -214,6 +329,52 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAndroidApp(self, request):
+        """删除安卓应用
+
+        :param request: Request instance for DeleteAndroidApp.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DeleteAndroidAppRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DeleteAndroidAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAndroidApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAndroidAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteAndroidAppVersion(self, request):
+        """删除安卓应用版本
+
+        :param request: Request instance for DeleteAndroidAppVersion.
+        :type request: :class:`tencentcloud.gs.v20191118.models.DeleteAndroidAppVersionRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.DeleteAndroidAppVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAndroidAppVersion", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAndroidAppVersionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAndroidInstanceImages(self, request):
         """删除安卓实例镜像
 
@@ -467,6 +628,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def FetchAndroidInstancesLogs(self, request):
+        """批量获取安卓实例日志
+
+        :param request: Request instance for FetchAndroidInstancesLogs.
+        :type request: :class:`tencentcloud.gs.v20191118.models.FetchAndroidInstancesLogsRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.FetchAndroidInstancesLogsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("FetchAndroidInstancesLogs", params, headers=headers)
+            response = json.loads(body)
+            model = models.FetchAndroidInstancesLogsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def InstallAndroidInstancesApp(self, request):
         """安装安卓实例应用
 
@@ -490,6 +674,52 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAndroidApp(self, request):
+        """修改安卓应用信息
+
+        :param request: Request instance for ModifyAndroidApp.
+        :type request: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidAppRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidAppResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAndroidApp", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAndroidAppResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyAndroidAppVersion(self, request):
+        """修改安卓应用版本
+
+        :param request: Request instance for ModifyAndroidAppVersion.
+        :type request: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidAppVersionRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidAppVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAndroidAppVersion", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAndroidAppVersionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAndroidInstanceInformation(self, request):
         """修改安卓实例的信息
 
@@ -536,6 +766,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAndroidInstancesInformation(self, request):
+        """批量修改安卓实例信息
+
+        :param request: Request instance for ModifyAndroidInstancesInformation.
+        :type request: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidInstancesInformationRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidInstancesInformationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAndroidInstancesInformation", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAndroidInstancesInformationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAndroidInstancesLabels(self, request):
         """修改安卓实例分辨率。需要注意的是该接口可能导致正在运行的应用出现闪退，所以建议在实例维护时期才进行调用。
 
@@ -559,6 +812,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyAndroidInstancesResolution(self, request):
+        """修改安卓实例分辨率。需要注意的是该接口需要重启才能生效。
+
+        :param request: Request instance for ModifyAndroidInstancesResolution.
+        :type request: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidInstancesResolutionRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.ModifyAndroidInstancesResolutionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAndroidInstancesResolution", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAndroidInstancesResolutionResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAndroidInstancesUserId(self, request):
         """批量修改安卓实例的用户ID
 
@@ -651,6 +927,29 @@ class GsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestoreAndroidInstanceFromStorage(self, request):
+        """指定存储还原云手机
+
+        :param request: Request instance for RestoreAndroidInstanceFromStorage.
+        :type request: :class:`tencentcloud.gs.v20191118.models.RestoreAndroidInstanceFromStorageRequest`
+        :rtype: :class:`tencentcloud.gs.v20191118.models.RestoreAndroidInstanceFromStorageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestoreAndroidInstanceFromStorage", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestoreAndroidInstanceFromStorageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SaveGameArchive(self, request):
         """保存游戏存档
 
